==> apache-tinkerpop-3.4.11-src.zip: tinkerpop-3.4.11/gremlin-driver/src/test/java/org/apache/tinkerpop/gremlin/driver/SerializationExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.apache.tinkerpop.gremlin.driver.ser.SerializationException;
import org.junit.Test;

import java.io.IOException;

public class SerializationExceptionTest {

    @Test
    public void testSerializationException() {
        try {
            throwException();
            fail("Serialization exception should have been thrown and caught");
        } catch (IOException e) {
            assertEquals(e.getMessage(), "no bueno");
        }
    }

    private static void throwException() throws SerializationException {
        throw new SerializationException("no bueno");
    }
}

==> apache-tinkerpop-3.8.0-src.zip: tinkerpop-3.8.0/gremlin-driver/src/test/java/org/apache/tinkerpop/gremlin/driver/SerializationExceptionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tinkerpop.gremlin.driver;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.apache.tinkerpop.gremlin.util.ser.SerializationException;
import org.junit.Test;

import java.io.IOException;

public class SerializationExceptionTest {

    @Test
    public void testSerializationException() {
        try {
            throwException();
            fail("Serialization exception should have been thrown and caught");
        } catch (IOException e) {
            assertEquals(e.getMessage(), "no bueno");
        }
    }

    private static void throwException() throws SerializationException {
        throw new SerializationException("no bueno");
    }
}
